function getMessage(messageName) {
  return chrome.i18n.getMessage(messageName);
}
/**解析函数集 */
const commonParse = {
  /** 解析地址 */
  parseAddress(responseObject) {
    let address = "";
    let country = "";
    let roadA = "";
    let roadB = "";
    try {
      const addressArray = responseObject[6][2];
      address = jointsQuote(addressArray.join(enums.joinString)); // 将所有地址部分拼接成字符串
      country = jointsQuote(addressArray[0]);
      roadA = jointsQuote(addressArray[1]);
      roadB = jointsQuote(addressArray[2]);
    } catch (error) {
      console.warn("解析地址时发生错误", error);
    }
    return [address || "", country || "", roadA || "" + roadB || ""];
  },
  /** 解析类型 */
  parseType(responseObject) {
    let type = "";
    try {
      const typeArray = responseObject[6][13]; 
      type = jointsQuote(typeArray.join(enums.joinString)); 
    } catch (error) {
      console.warn("解析类型时发生错误", error);
    }
    return type || "";
  },
  /** 解析时间区 */
  parseTimeZone(responseObject) {
    let timeZone = "";
    try {
      timeZone = jointsQuote(responseObject[6][30]);
    } catch (error) {
      console.warn("解析解析时间区时发生错误", error);
    }
    return timeZone;
  },
  /** 解析位置 */
  parseLocation(responseObject) {
    let location1 = "";
    let location2 = "";
    try {
      location1 = jointsQuote((+responseObject[4][0][1]).toFixed(2));
      location2 = jointsQuote((+responseObject[4][0][2]).toFixed(8));
    } catch (error) {
      console.warn("解析位置时发生错误", error);
    }
    return [location1 || "", location2 || ""];
  },
  /** 解析设施 */
  parseFacilities(responseObject) {
    let facilitiesText = "";
    try {
      const facilitiesArray = responseObject[6][64][2];
      facilitiesArray.forEach((facility) => {
        const facilityInfo = facility.slice(2);
        if (facilityInfo[1] === 1) {
          facilitiesText += facilitiesText ? `${enums.joinString} ${facilityInfo[0]}` : facilityInfo[0];
        }
      });
      facilitiesText = jointsQuote(facilitiesText);
    } catch (error) {
      console.warn("解析设施时发生错误", error);
    }
    return facilitiesText || "";
  },
  /** 解析ID */
  parseId(responseObject, enText) {
    let cid = "";
    let pid = "";
    let fid = "";
    try {
      cid = jointsQuote(sliceAssignedText(enText, "ludocid%5Cu003d", "%5C"));
      pid = jointsQuote(responseObject[6][78]);
      fid = jointsQuote(responseObject[6][10]);
    } catch (error) {
      console.warn("解析ID时发生错误", error);
    }
    return [cid || "", pid || "", fid || ""];
  },
  /** 解析链接与封面 */
  parseLinkAndCover(responseObject) {
    let url = "";
    try {
      url = jointsQuote(responseObject[6][4][3][0]); 
    } catch (error) {
      console.warn("解析链接与封面时发生错误", error);
    }
    return url;
  },
  /** 解析评分与评价 */
  parseRatingAndReviews(responseObject) {
    let rating = "";
    let reviewCount = "";
    try {
      rating = jointsQuote(responseObject[6][4][7]);
      reviewCount = jointsQuote(responseObject[6][4][8]);
    } catch (error) {
      console.warn("解析评分与评价时发生错误", error);
    }
    return [rating || "", reviewCount || ""];
  },
  /** 解析官网域名 */
  parseDomain(responseObject) {
    let websiteLink = "";
    let domainName = "";
    try {
      websiteLink = jointsQuote(responseObject[6][7][0]); 
      domainName = jointsQuote(responseObject[6][7][1]); 
    } catch (error) {
      console.warn("解析官网域名时发生错误", error);
    }
    return [domainName || "", websiteLink || ""];
  },
  /** 解析联系方式 */
  parsePhoneNumbers(responseObject) {
    let mainPhone = "";
    let phoneNumbers = "";
    try {
      const phoneInfo = responseObject[6][178][0];
      mainPhone = jointsQuote(phoneInfo[0]);
      phoneInfo[1].forEach((phone) => {
        phoneNumbers += phoneNumbers ? `${enums.joinString} ${phone[0]}` : phone[0];
      });
      phoneNumbers = jointsQuote(phoneNumbers);
    } catch (error) {
      console.warn("解析联系方式时发生错误", error);
    }
    return [mainPhone || "", phoneNumbers || ""];
  },
  /** 解析营业时间 */
  parseBusinessHours(responseObject) {
    let businessHours = "";
    try {
      const hoursArray = responseObject[6][34][1]; 
      hoursArray.forEach((hours) => {
        const formattedHours = `${hours[0]}: [${hours[1]}]`;
        businessHours += businessHours ? `${enums.joinString} ${formattedHours}` : formattedHours;
      });
      businessHours = jointsQuote(businessHours);
    } catch (error) {
      console.warn("解析营业时间时发生错误", error);
    }
    return businessHours || "";
  },
  /** 解析名称 */
  parseName(responseObject) {
    let name = "";
    try {
      name = jointsQuote(responseObject[6][11]);
    } catch (error) {}
    return name || "";
  }
}

// 初始化容器和脚本
function initScript() {
  if(document.getElementById("fixedBox")) {
    return;
  }
  // 父容器盒子
  const parentBox = getParentElement();
  
  // 创建一个固定定位容器
  const fixedBox = document.createElement("div");
  fixedBox.id = "fixedBox";
  setElementStyles(fixedBox, {
    position: "fixed",
    left:
      getAncestorElement(parentBox, 7).offsetLeft +
      getAncestorElement(parentBox, 7).offsetWidth +
      20 +
      "px",
    top: "72px",
    width: "340px",
    height: "588px",
    backgroundColor: "#fefefe",
    borderRadius: "8px",
    boxShadow: "3px 3px 8px -2px #666",
    overflow: "hidden",
    display: "none",
  });

  // 顶部区域
  const titleBox = document.createElement("div");
  setElementStyles(titleBox, {
    height: "40px",
    // backgroundColor: "#886fff",
    background: "linear-gradient(110deg, #FFD9E8 4%, #FFD9E8 40%, #DE95BA calc(40% + 1px), #DE95BA 50%, #7F4A88 calc(50% + 1px), #7F4A88 70%, #4A266A calc(70% + 1px), #4A266A 100%)",
    display: "flex"
  })
  // 关闭按钮
  const closeBoxButton = document.createElement("button");
  closeBoxButton.id = "closeBoxButton";
  closeBoxButton.innerText = "×";
  setElementStyles(closeBoxButton, {
    fontSize: "28px",
    color: "#fff",
    cursor: "pointer",
    marginLeft: "auto",
    marginRight: "12px",
  });
  closeBoxButton.onclick = function() {
    document.getElementById("captureLi").click();
  }
  titleBox.appendChild(closeBoxButton);
  fixedBox.appendChild(titleBox);
  

  // 装按钮的容器
  const buttonBox = document.createElement("div");
  setElementStyles(buttonBox, {
    display: "flex",
    padding: "14px 22px"
  })

  // 开始抓取按钮
  const startToGrabButton = document.createElement("button");
  startToGrabButton.id = "startToGrabButton";
  startToGrabButton.title = chrome.i18n.getMessage("startToGrab");
  startToGrabButton.innerHTML = `<svg t="1726892363386" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="4714" width="32" height="32"><path d="M512 96C282.624 96 96 282.624 96 512s186.624 416 416 416 416-186.624 416-416S741.376 96 512 96z m0 768C317.92 864 160 706.08 160 512S317.92 160 512 160s352 157.92 352 352-157.92 352-352 352z" p-id="4715" fill="#ffffff"></path><path d="M466.816 324.96a32 32 0 0 0-50.816 25.888v339.776a32 32 0 0 0 50.816 25.856l233.6-169.888a32 32 0 0 0 0-51.776l-233.6-169.856z" p-id="4716" fill="#ffffff"></path></svg>`;
  setElementStyles(startToGrabButton, buttonStyles);
  setElementStyles(startToGrabButton, {
    backgroundColor: "red",
    color: "#fff",
  });
  
  let stopGetContentFn;
  startToGrabButton.onclick = async function () {
    removeDBDataList(db);
    startToGrabButton.style.display = "none";
    stopToGrabButton.style.display = "flex";
    parentBox.style.backgroundColor = "#e1e36b8a";
    stopGetContentFn = await getContentAndToData();
  };
  buttonBox.appendChild(startToGrabButton);


  // 停止抓取按钮
  const stopToGrabButton = document.createElement("button");
  stopToGrabButton.id = "stopToGrabButton";
  stopToGrabButton.title = chrome.i18n.getMessage("stopToGrab");
  stopToGrabButton.innerHTML = `<svg t="1726892624004" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="5788" width="32" height="32"><path d="M910.8 303.6c-5.4-10.5-16.3-17.8-28.9-17.8-17.8 0-32.2 14.4-32.2 32.1 0 6 1.7 11.7 4.6 16.5l-0.1 0.1c26.9 52.4 42.1 111.8 42.1 174.7 0 211.6-171.6 383.2-383.2 383.2S129.8 720.8 129.8 509.2 301.4 126.1 513 126.1c62.5 0 121.5 15 173.6 41.5l0.2-0.4c4.6 2.6 10 4.1 15.7 4.1 17.8 0 32.2-14.4 32.2-32.1 0-13.1-7.9-24.4-19.3-29.4C654.6 78.9 585.9 61.5 513 61.5 265.7 61.5 65.3 262 65.3 509.2S265.7 956.9 513 956.9s447.7-200.4 447.7-447.7c0-74.1-18-144-49.9-205.6z" fill="#515151" p-id="5789"></path><path d="M385.4 352.2V672c0 17.5 14.3 31.9 31.9 31.9 17.6 0 32-14.4 31.9-31.9V352.2c0-17.5-14.3-31.9-31.9-31.9-17.5 0-31.9 14.3-31.9 31.9zM578.9 352.2V672c0 17.5 14.3 31.9 31.9 31.9 17.5 0 31.9-14.4 31.9-31.9V352.2c0-17.5-14.3-31.9-31.9-31.9-17.5 0-31.9 14.3-31.9 31.9z" fill="#515151" p-id="5790"></path><path d="M772.7 217.7a32.2 32.1 0 1 0 64.4 0 32.2 32.1 0 1 0-64.4 0Z" fill="#515151" p-id="5791"></path></svg>`;
  setElementStyles(stopToGrabButton, buttonStyles);
  setElementStyles(stopToGrabButton, {
    backgroundColor: "#fff",
    color: "#333",
    border: "1px solid #ccc",
    display: "none",
  });
  stopToGrabButton.onclick = function () {
    stopGetContentFn && stopGetContentFn();
  };
  buttonBox.appendChild(stopToGrabButton);


  // 导出表格按钮
  const exportFormButton = document.createElement("button");
  exportFormButton.id = "exportFormButton";
  exportFormButton.title = chrome.i18n.getMessage("exportForm");
  exportFormButton.innerHTML = `<svg t="1726893104972" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="6937" width="32" height="32"><path d="M325.68 222.44H98.57v-59.89h227.11v59.89z" p-id="6938" fill="#ffffff"></path><path d="M154.91 893.24H98.57v-676.1h56.34v676.1z m732.44 0H154.91V836.9h732.44v56.34z m0-56.34h-56.34V555.19h56.34V836.9z" p-id="6939" fill="#ffffff"></path><path d="M927.4 382.27L645.53 135.09v494.36z" p-id="6940" fill="#ffffff"></path><path d="M646.91 476.83V250.9C494.01 294.62 381.3 444.7 381.3 623.19c0 39.29 5.49 77.19 15.64 112.91 35.95-126.5 130.75-225.16 249.97-259.27z" p-id="6941" fill="#ffffff"></path></svg>`;
  setElementStyles(exportFormButton, buttonStyles);
  setElementStyles(exportFormButton, {
    backgroundColor: "#5bc0de",
    color: "#fff",
  });
  exportFormButton.onclick = function() {
    ExportForm(db);
  };
  buttonBox.appendChild(exportFormButton);
  fixedBox.appendChild(buttonBox);


  // 抓取的文本内容容器
  const textareaBox = document.createElement("textarea");
  textareaBox.id = "logTextarea";
  setElementStyles(textareaBox, {
    width: "95%",
    height: "430px",
    marginLeft: "10px",
    padding: "20px",
    boxSizing: "border-box",
    resize: "none",
    fontSize: "14px"
  });
  fixedBox.appendChild(textareaBox);

  // 底部统计数量容器
  const infoTipBox = document.createElement("div");
  infoTipBox.id = "infoTipBox";
  setElementStyles(infoTipBox, {
    display: "flex",
    justifyContent: "space-between",
    margin: "8px 26px 0",
    paddingTop: "4px",
    borderTop: "1px solid #ccc",
    fontSize: "14px"
  });
  // 当前抓取数量与DB中的数量
  infoTipBox.innerHTML = `
    <span id="grabCount">${getMessage("bu_huo")}[0]</span>
    <span id="DBCount">${getMessage("chu_chun")}<span id="DBCouns">[0]</span></span>
  `
  fixedBox.appendChild(infoTipBox);

  document.body.appendChild(fixedBox);

  // -------------------------------------------------
  function timeIntervalUpdateDBCount() {
    if (document.getElementById("fixedBox").style.display === "none") {
      return;
    }
    const transaction = db.transaction(["ArrayObjectStore"], "readonly");
    const objectStore = transaction.objectStore("ArrayObjectStore");
    // 获取对象存储空间的全部数据
    const request = objectStore.count();
    request.onsuccess = function (event) {
      document.getElementById("DBCouns").innerText = `[${event.target.result}]`;
    }
  }
  // 每秒更新一次DB数据库中的数量
  timeIntervalUpdateDBCount();
  setInterval(timeIntervalUpdateDBCount, 1200);
}

/**获取列表内容并转换为数据 */
async function getContentAndToData() {
  let isRunning = true;

  function stopFunction() {
    Message(getMessage("ti_shi"));
    document.getElementById("stopToGrabButton").innerHTML = `<svg t="1726910254697" class="icon rotate-animation" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="4523" width="32" height="32"><path d="M144.205 202.496a136.678 136.678 0 1 0 273.357 0 136.678 136.678 0 1 0-273.357 0zM41.728 492.902a119.578 119.578 0 1 0 239.155 0 119.578 119.578 0 1 0-239.155 0zM144.23 749.158a102.502 102.502 0 1 0 205.005 0 102.502 102.502 0 1 0-205.005 0zM435.2 861.926a89.6 89.6 0 1 0 179.2 0 89.6 89.6 0 1 0-179.2 0z m289.843-95.666a85.427 85.427 0 1 0 170.855 0 85.427 85.427 0 1 0-170.855 0z m136.704-290.433a68.326 68.326 0 1 0 136.653 0 68.326 68.326 0 1 0-136.653 0zM759.22 219.571a51.251 51.251 0 1 0 102.502 0 51.251 51.251 0 1 0-102.503 0zM512 85.376a34.176 34.176 0 1 0 68.352 0 34.176 34.176 0 1 0-68.352 0z" p-id="4524"></path></svg>`
    isRunning = false;
  };

  const parentElement = getParentElement();
  // 获取一次当前列表所有元素数据
  async function getCurrentAllList() {
    if (parentElement) {
      for (let i = 0; i < parentElement.children.length; i++) {
        const sds = parentElement.children[i];
        if (sds.innerHTML.indexOf(`class="${enums.aLinkElementClass}"`, 0) !== -1) {
          if (
            sds.innerHTML.indexOf("赞助商·广告主：", 0) === -1 &&
            sds.innerHTML.indexOf("已抓取", 0) === -1
          ) {
            const anchorElement = sds.querySelector(`.${enums.aLinkElementClass}`);
            const hrefValue = anchorElement
              ? anchorElement.getAttribute("href")
              : null;

            anchorElement.setAttribute("qx_hook", "已抓取");

            try {
              const data = await fetchText(hrefValue);
              const text = sliceAssignedText(
                data,
                "APP_INITIALIZATION_STATE=",
                ";window.APP_FLAGS"
              );
              const parseText = JSON.parse(text);
              const parseData = parseSearchContent(parseText[3][6], sds);
              addDBDataList(db, parseData);
              // 等待0.2秒等图片加载出来，时间太短拿不到封面图
              await sleep(200);
            } catch (error) {
              console.error("发送请求失败, 地图详情页:", error);
            }
          }
        }
      }
    }
  };
  
  // 判断是否抓取完所有数据, 无数据时最后一个元素会提示"没有其他结果了。"
  LoopWaitingToGetTheElement(parentElement, function(lastElement) {
    if (lastElement.innerHTML.includes("没有其他结果了") || lastElement.innerHTML.includes("You've reached the end of the list")) {
      return true;
    } else {
      if (!isRunning) {
        return true;
      }
      getCurrentAllList().then(res => {
        parentElement.scrollTo({
          top: parentElement.scrollHeight,
          behavior: "smooth",
        });
      });
    }
  }).then(async checkGetAll => {
    // 全部获取完成, 导出表
    if (checkGetAll) {
      await getCurrentAllList();
      // 等待三秒，让停止抓取前的业务正确结束，否则结束后导出的数据缺少
      await sleep(3000);
      document.getElementById("startToGrabButton").style.display = "flex";
      document.getElementById("stopToGrabButton").style.display = "none";
      document.getElementById("stopToGrabButton").innerHTML = `<svg t="1726892624004" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="5788" width="32" height="32"><path d="M910.8 303.6c-5.4-10.5-16.3-17.8-28.9-17.8-17.8 0-32.2 14.4-32.2 32.1 0 6 1.7 11.7 4.6 16.5l-0.1 0.1c26.9 52.4 42.1 111.8 42.1 174.7 0 211.6-171.6 383.2-383.2 383.2S129.8 720.8 129.8 509.2 301.4 126.1 513 126.1c62.5 0 121.5 15 173.6 41.5l0.2-0.4c4.6 2.6 10 4.1 15.7 4.1 17.8 0 32.2-14.4 32.2-32.1 0-13.1-7.9-24.4-19.3-29.4C654.6 78.9 585.9 61.5 513 61.5 265.7 61.5 65.3 262 65.3 509.2S265.7 956.9 513 956.9s447.7-200.4 447.7-447.7c0-74.1-18-144-49.9-205.6z" fill="#515151" p-id="5789"></path><path d="M385.4 352.2V672c0 17.5 14.3 31.9 31.9 31.9 17.6 0 32-14.4 31.9-31.9V352.2c0-17.5-14.3-31.9-31.9-31.9-17.5 0-31.9 14.3-31.9 31.9zM578.9 352.2V672c0 17.5 14.3 31.9 31.9 31.9 17.5 0 31.9-14.4 31.9-31.9V352.2c0-17.5-14.3-31.9-31.9-31.9-17.5 0-31.9 14.3-31.9 31.9z" fill="#515151" p-id="5790"></path><path d="M772.7 217.7a32.2 32.1 0 1 0 64.4 0 32.2 32.1 0 1 0-64.4 0Z" fill="#515151" p-id="5791"></path></svg>`;
      getParentElement().style.backgroundColor = "#00000000";
      ExportForm(db);
    }
  })
  
  return stopFunction;
}

/**解析数据 */
function parseSearchContent(data, element) {
  const enText = encodeURIComponent(data).replace(")%5D%7D'%0A", "");
  const decodedString = decodeURIComponent(enText);
  const responseObject = JSON.parse(decodedString);

  const name = commonParse.parseName(responseObject) || "";
  const address = commonParse.parseAddress(responseObject) || "";
  const type = commonParse.parseType(responseObject) || "";
  const timeZone = commonParse.parseTimeZone(responseObject) || "";
  const facilities = commonParse.parseFacilities(responseObject) || "";
  const phone = commonParse.parsePhoneNumbers(responseObject) || "";
  const giveAMark = commonParse.parseRatingAndReviews(responseObject) || "";
  const place = commonParse.parseLocation(responseObject) || "";
  const hid = commonParse.parseId(responseObject, enText) || "";
  const domain = commonParse.parseDomain(responseObject) || "";
  const links = commonParse.parseLinkAndCover(responseObject) || "";
  const businessHours = commonParse.parseBusinessHours(responseObject) || "";
  const featuredImage = element.querySelector("img")?.src || "";
  let cidLinks = "";
  if (hid[0] != null) {
    cidLinks = "https://www.google.com/maps?cid=" + hid[0].replace(/\D/g, '');
  }

  addLog(name);
  return [
    name,                     // "Name"
    "",                       // "Description"
    address[0],               // "Fulladdress"
    address[1],               // "Street"
    address[2],               // "Municipality"
    type,                     // "Categories"
    timeZone,                 // "Time Zone"
    facilities,               // "Amenities"
    phone[0],                 // "Phone"
    phone[1],                 // "Phones"
    decodedString.includes("https://business.google.com/create") ? "NO" : "YES",                       // "Claimed"
    giveAMark[1],             // "Review Count"
    giveAMark[0],             // "Average Rating
    links,                    // "Review URL"
    cidLinks,                 // "Google Maps URL"
    place[1],                 // "Latitude"
    place[0],                 // "Longitude"
    domain[1],                // "Website"
    domain[0],                // "Domain"
    businessHours,            // "Opening Hours"
    featuredImage,            // "Featured Image"
    hid[0],                   // "Cid"
    hid[2],                   // "Fid"
    hid[1],                   // "Place Id"
  ];
}

/**初始化右侧菜单的按钮 */
function initMenuLi() {
  const ul = document.querySelector(`.${enums.ulShowElementClass}`);
  // 找到分割线索引
  const lastElement = Array.from(ul.children).find(element => element.tagName === "DIV");
  const newLi = document.createElement("li");
  newLi.id = "captureLi";
  newLi.innerHTML = `
    <button aria-current="false" class="wR3cXd">
      <div class="NP7r5c">
        <span class="cc4Ofc avo2Le google-symbols" aria-hidden="true" style="font-size: 24px;">
          <svg t="1726836737042" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="4243" width="24" height="24"><path d="M928 538.656h-128v-177.344l86.08-82.176a32 32 0 1 0-44.192-46.304L750.624 320H273.376L182.08 232.864a31.968 31.968 0 1 0-44.16 46.272L224 361.344v177.344H96a32 32 0 0 0 0 64h128V640c0 52.96 14.304 102.592 39.232 145.216L137.92 904.864a32 32 0 1 0 44.192 46.304l119.712-114.272a287.104 287.104 0 0 0 178.208 89.344V544a32 32 0 0 1 64 0v382.24a287.424 287.424 0 0 0 178.208-89.344l119.712 114.272a32.032 32.032 0 0 0 44.192-46.304l-125.344-119.648A287.04 287.04 0 0 0 800 640v-37.344h128a32 32 0 0 0 0-64z" p-id="4244" fill="#70757a"></path><path d="M672 240a160 160 0 0 0-320 0v21.344h320V240z" p-id="4245" fill="#70757a"></path></svg>
        </span> 
      </div> 
      <div class="d0UoQ TUxXbd" style="font-family: 'Google Sans', Roboto, 'Noto Sans SC', Arial, sans-serif;"> 
        <div class="cGRe9e tujHCe">${getMessage("zhua_qu")}</div> 
      </div> 
    </button>
  `;

  newLi.onclick = function(e) {
    const duration = 360;
    const liElement = e.target;

    // 初始化脚本、创建基本按钮页面
    initScript();

    // 获取li的坐标
    const { x: liX, y: liY } = liElement.getBoundingClientRect();
    const fixedBoxElement = document.getElementById("fixedBox");
    const { x: boxX, y: boxY }  = fixedBoxElement.getBoundingClientRect();

    // 显隐动画
    if (fixedBoxElement.style.display == "none") {
      const parentBox = getParentElement();
      fixedBoxElement.style.display = "block";
      fixedBoxElement.animate([
        { width: "0px", height: "0px", top: liY + "px", left: liX + "px", opacity: 0.6 },
        { width: "340px", height: "588px", top: "72px", left: getAncestorElement(parentBox, 7).offsetLeft + getAncestorElement(parentBox, 7).offsetWidth + 20 + "px", opacity: 1 }
      ], { duration, fill: "forwards" })
    } else {
      fixedBoxElement.animate([
        { width: "340px", height: "588px", top: boxY + "px", left: boxX + "px" },
        { width: "0px", height: "0px", top: liY + "px", left: liX + "px", opacity: 0.6 }
      ], { duration, fill: "forwards" })
      setTimeout(() => {
        fixedBoxElement.style.display = "none";
      }, duration);
    }
  }
  ul.insertBefore(newLi, lastElement || ul.children[0]);
}

window.onload = async function () {
  if (window.location.href.includes("google")) {
    console.log("content-script.js");
    // 初始化入口
    initMenuLi()
    // 创建style样式组
    const style = document.createElement('style');
    style.innerHTML = commonStyles;

    document.head.appendChild(style);
  }
};
